INDEPENDENT {t FROM 0 TO 1 WITH 1 (ms)}

NEURON {
	POINT_PROCESS APTrig
	RANGE n, thresh, time, delay, mag
	POINTER pstim
}

UNITS {
	(mV) = (millivolt)
	(umho) = (micromho)
}

PARAMETER {
	thresh = -20 (mV)
	delay = 1 (ms)
	mag = 0 (umho)
}

ASSIGNED {
	n
	firing
	trigger
	time (ms)
	pstim (umho)
}

INITIAL {
	n = 0
	firing = 0
	trigger = 0
	check()
}

BREAKPOINT {
	SOLVE check
}

PROCEDURE check() {
VERBATIM
	/* prime trigger when v reaches threshold */
	if (v >= thresh && !firing && !trigger) {
		/* note: we miss a pulse (or get it late) if firing occurs
			before last trigger was handled
			 in general one needs a list of length
			 MaxDelay/ShortestTimeBetweenPulses */
		firing = 1;
		time = t;
		trigger = 1;
		n += 1.;
	}
	/* only when v returns below threshold can the trigger be primed */
	if (firing && v < thresh) {
		firing = 0;
	}
	/* trigger occurs after delay */
	if (trigger) {
		if (t >= time + delay) {
			trigger = 0;
			if (&(pstim)) {
				pstim += mag;
			}
		}
	}
	return 0;
ENDVERBATIM
}
