COMMENT
alpha function synapse implemented as continuously integrated
kinetic scheme a la Srinivasan and Chiel (Neural Computation) so that
one can give many stimuli which summate.
ENDCOMMENT

COMMENT
a synaptic current with alpha function conductance defined by
        i = g * (v - e)      i(nanoamps), g(micromhos);
        where
         g = 0 for t < onset and
         g = stim * (t - onset)/tau * exp(-(t - onset - tau)/tau)
          for t > onset
this has the property that the maximum value is gmax and occurs at
 t = delay + tau.
ENDCOMMENT
					       
INDEPENDENT {t FROM 0 TO 1 WITH 1 (ms)}

NEURON {
	POINT_PROCESS TrigSyn
	RANGE tau, stim, e, i
	NONSPECIFIC_CURRENT i
}
UNITS {
	(nA) = (nanoamp)
	(mV) = (millivolt)
	(umho) = (micromho)
}

PARAMETER {
	tau=.1 (ms)
	stim=0 	(umho)
	e=0	(mV)
	v	(mV)
}

ASSIGNED {
	i (nA)
	bath (umho)
	k (/ms)
}

STATE {
	A (umho)
	G (umho)
}

INITIAL {
	k = 1/tau
	stim = 0
	A = 0
	G = 0
}

BREAKPOINT {
	SOLVE conductance
	i = G*(v - e)
}

PROCEDURE conductance() {
	A = A + stim
	stim = 0
	SOLVE state METHOD sparse
	VERBATIM
	return 0;
	ENDVERBATIM
}

KINETIC state {
	~ A <-> G	(k, 0)
	~ G <-> bath	(k, 0)
}
